@@ -26,8 +26,6 @@
 #include "ctkevent.h"
 #include "ctkconfig.h"
 
-#include "NvCtrlAttributes.h"
-
 G_BEGIN_DECLS
 
 #define CTK_TYPE_GPU (ctk_gpu_get_type())
@@ -55,16 +53,34 @@ struct _CtkGpu
 {
     GtkVBox parent;
 
-    NvCtrlAttributeHandle *handle;
+    CtrlTarget *ctrl_target;
     CtkConfig *ctk_config;
     CtkEvent *ctk_event;
 
     GtkWidget *displays;
     GtkWidget *gpu_memory_used_label;
+    GtkWidget *gpu_utilization_label;
+    GtkWidget *video_utilization_label;
+    GtkWidget *pcie_utilization_label;
     gint gpu_memory;
+    gint gpu_utilization;
     gint gpu_cores;
+    gint gpu_uuid;
     gint memory_interface;
+    gboolean resizable_bar;
     gboolean pcie_gen_queriable;
+
+    gboolean video_ram_available;
+    gboolean link_speed_available;
+    gboolean graphics_util_available;
+    gboolean video_util_available;
+    gboolean pcie_util_available;
+
+    gboolean bus_type_available;
+    gboolean bus_id_available;
+    gboolean pci_device_id_available;
+    gboolean pci_vendor_id_available;
+    gboolean irq_available;
 };
 
 struct _CtkGpuClass
@@ -73,15 +89,12 @@ struct _CtkGpuClass
 };
 
 GType       ctk_gpu_get_type (void) G_GNUC_CONST;
-GtkWidget*  ctk_gpu_new      (NvCtrlAttributeHandle *handle,
-                              CtrlHandleTarget *t,
+GtkWidget*  ctk_gpu_new      (CtrlTarget *ctrl_target,
                               CtkEvent *ctk_event,
                               CtkConfig *ctk_config);
 
-void get_bus_type_str(NvCtrlAttributeHandle *handle,
-                      gchar **bus);
-void get_bus_id_str(NvCtrlAttributeHandle *handle,
-                    gchar **pci_bus_id);
+void get_bus_type_str(CtrlTarget *ctrl_target, gchar **bus);
+gchar *get_bus_id_str(CtrlTarget *ctrl_target);
 
 GtkTextBuffer *ctk_gpu_create_help(GtkTextTagTable *,
                                    CtkGpu *);
